summaryrefslogtreecommitdiffstats
path: root/android_webview/browser
diff options
context:
space:
mode:
authoryfriedman@chromium.org <yfriedman@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-04-03 00:20:00 +0000
committeryfriedman@chromium.org <yfriedman@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-04-03 00:20:00 +0000
commitb8ec98a368e8236d57d39d27e516079ab8697bfb (patch)
treea47d1535fc1e2d74a9f871391bf9d223b2e5cc87 /android_webview/browser
parent4ba63f3ea1aba43509553cc1838c8d35037b73bd (diff)
downloadchromium_src-b8ec98a368e8236d57d39d27e516079ab8697bfb.zip
chromium_src-b8ec98a368e8236d57d39d27e516079ab8697bfb.tar.gz
chromium_src-b8ec98a368e8236d57d39d27e516079ab8697bfb.tar.bz2
[Android] Fix remaining linker errors for components build
Miscellaneous missing dependencies and a few more exports. BUG=158821 Review URL: https://chromiumcodereview.appspot.com/12988003 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@191944 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'android_webview/browser')
-rw-r--r--android_webview/browser/net/aw_url_request_job_factory.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/android_webview/browser/net/aw_url_request_job_factory.cc b/android_webview/browser/net/aw_url_request_job_factory.cc
index c14cd17..3777a81 100644
--- a/android_webview/browser/net/aw_url_request_job_factory.cc
+++ b/android_webview/browser/net/aw_url_request_job_factory.cc
@@ -47,10 +47,10 @@ URLRequestJob* AwURLRequestJobFactory::MaybeCreateJobWithProtocolHandler(
if (job)
return job;
- // If the URLRequestJobManager supports the scheme NULL should be returned
- // from this method. In that case the built in handlers in
- // URLRequestJobManager will then be used to create the job.
- if (net::URLRequestJobManager::GetInstance()->SupportsScheme(scheme))
+ // If URLRequest supports the scheme NULL should be returned from this method.
+ // In that case the built in handlers will then be used to create the job.
+ // NOTE(joth): See the assumption in IsHandledProtocol above.
+ if (net::URLRequest::IsHandledProtocol(scheme))
return NULL;
return new net::URLRequestErrorJob(